# Init-Film  
![image](https://github.com/user-attachments/assets/9d9dd462-6b83-4ac7-a3d9-4efb88e4fb72)  
Tired of manually creating folder structures for your film/video projects?  
Want a folder structure that dynamically changes based on the needs for your project?  
Then Init-Film was made for you!  
By filmmakers, for filmmakers ;)  
### ->>[Watch showcase](https://www.youtube.com/watch?v=QheWe-1PqUM)<<-  


## Before installing:  
Make sure you have any of the following [Python](https://www.python.org/) versions installed (tested with tox):  
  - [3.13](https://www.python.org/downloads/release/python-3132/) (recommended)  
  - [3.12](https://www.python.org/downloads/release/python-3129/)  
  - [3.11](https://www.python.org/downloads/release/python-3119/)  
  - [3.10](https://www.python.org/downloads/release/python-31011/)  
  - [3.9](https://www.python.org/downloads/release/python-3913/)  


## Installation:  
### Method 1 (from PyPi):  
[Watch YouTube tutorial](https://www.youtube.com/watch?v=Z5_rhFlNFM8)  
Use `pip install init-film` to install the latest version of init-film.  

### Method 2 (from source):  
[Watch YouTube tutorial](https://www.youtube.com/watch?v=oiKy_RU5WHE)  
1. Download the repo by using `git clone https://github.com/andreasdelabie/init-film` or download the zip folder from the [releases](https://github.com/andreasdelabie/init-film/releases).  
2. Navigate to the folder by using `cd [path to folder]` or using a file explorer.  
3. Use `pip install .` to install the script.

### Error: externally-managed-environment
![image](https://github.com/user-attachments/assets/71cae57b-8baf-4a1f-b0ac-3bbf978bff38)  
Check out the documentation for [externally managed environments](https://github.com/andreasdelabie/init-film/blob/main/README-ExternallyManagedEnvironments.md).


## Usage:  
[Watch showcase](https://www.youtube.com/watch?v=QheWe-1PqUM)  
### Basic usage:  
Use the CLI command `init-film` in any folder to start a new film/video project.  
### Custom folder names:  
Folder names can't contain spaces (with the exception of the project name). Instead use a `-` or `_`.  
### Add shortcut to Windows context menu (right click menu):  
Use `init-film --add-shortcut` to add Init-Film to your Windows context menu.  
Use `init-film --remove-shortcut` to remove it.  
### Help:  
Use `init-film --help` or `init-film -h` to show the help screen.  


## Updating:  
Use `pip install --upgrade init-film` to update to the latest version of init-film.  


## Uninstalling:  
Use `pip uninstall init-film` to fully uninstall init-film from your system.


## Support:  
<a href="https://www.buymeacoffee.com/andreasdelabie"><img src="https://img.buymeacoffee.com/button-api/?text=Buy me a coffee&emoji=☕&slug=andreasdelabie&button_colour=FFDD00&font_colour=000000&font_family=Comic&outline_colour=000000&coffee_colour=ffffff"/></a>  
